/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QABSTRACTANIMATION_H
#define QABSTRACTANIMATION_H

#include <QtCore/qobject.h>

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)

class QtAnimationGroup;
class QtSequentialAnimationGroup;

class QtAbstractAnimationPrivate;
class Q_ANIMATION_EXPORT QtAbstractAnimation : public QObject
{
    Q_OBJECT
    Q_PROPERTY(State state READ state NOTIFY stateChanged)
    Q_PROPERTY(int loopCount READ loopCount WRITE setLoopCount)
    Q_PROPERTY(int currentTime READ currentTime WRITE setCurrentTime)
    Q_PROPERTY(int currentLoop READ currentLoop NOTIFY currentLoopChanged)
    Q_PROPERTY(Direction direction READ direction WRITE setDirection)
    Q_PROPERTY(int duration READ duration)

public:
    enum Direction {
        Forward,
        Backward
    };

    enum State {
        NotRunning,
        Paused,
        Running
    };

    enum DeletionPolicy {
        KeepWhenStopped = 0,
        DeleteWhenStopped
    };

    QtAbstractAnimation(QObject *parent = 0);
    virtual ~QtAbstractAnimation();

    State state() const;

    QtAnimationGroup *group() const;

    Direction direction() const;
    void setDirection(Direction direction);

    int loopCount() const;
    void setLoopCount(int loopCount);
    int currentLoop() const;

    virtual int duration() const = 0;
    int totalDuration() const;

    int currentTime() const;

Q_SIGNALS:
    void started();
    void stopped();
    void finished();
    void stateChanged(QtAbstractAnimation::State oldState, QtAbstractAnimation::State newState);
    void currentLoopChanged(int currentLoop);

public Q_SLOTS:
    void start(QtAbstractAnimation::DeletionPolicy policy = KeepWhenStopped);
    void pause();
    void resume();
    void stop();
    void setCurrentTime(int msecs);

protected:
    QtAbstractAnimation(QtAbstractAnimationPrivate &dd, QObject *parent = 0);
    bool event(QEvent *event);

    virtual void updateCurrentTime(int msecs) = 0;
    virtual void updateState(QtAbstractAnimation::State oldState, QtAbstractAnimation::State newState);
    virtual void updateDirection(QtAbstractAnimation::Direction direction);

#ifdef QT_EXPERIMENTAL_SOLUTION
     QtAbstractAnimationPrivate *d_ptr;
#endif

private:
    Q_DISABLE_COPY(QtAbstractAnimation)
    Q_DECLARE_PRIVATE(QtAbstractAnimation)

    friend class QUnifiedTimer;

    // ### avoid these friends
    friend class QtAnimationGroup;
    friend class QtSequentialAnimationGroup;
};
QT_END_NAMESPACE

QT_END_HEADER

#endif // QABSTRACTANIMATION_H
