/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QABSTRACTSTATEGROUP_H
#define QABSTRACTSTATEGROUP_H

#ifndef QT_STATEMACHINE_SOLUTION
#include <QtCore/qabstractstate.h>
#else
#include "qabstractstate.h"
#endif

#include <QtCore/qlist.h>
#include <QtCore/qvariant.h>

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)

#ifndef QT_NO_ANIMATION
class QtAnimationState;
class QtAbstractAnimation;
#endif

class QtAbstractTransition;
class QtHistoryState;
class QtStateAction;

class QtAbstractStateGroupPrivate;
class Q_ANIMATION_EXPORT QtAbstractStateGroup : public QtAbstractState
{
    Q_OBJECT
public:
    enum HistoryType {
        ShallowHistory,
        DeepHistory
    };

    enum RestorePolicy {
        GlobalRestorePolicy,
        DoNotRestoreProperties,
        RestoreProperties
    };

    ~QtAbstractStateGroup();

    QtAbstractState *errorState() const;
    void setErrorState(QtAbstractState *state);

    void addTransition(QtAbstractTransition *transition, QtAbstractState *target);
    void addTransition(QtAbstractTransition *transition, const QList<QtAbstractState*> &targets);
    void addTransition(const QObject *sender, const char *signal, QtAbstractState *target);
    void addTransition(QtAbstractTransition *transition);
    void addTransition(QtAbstractState *target);
    void addFinishedTransition(QtAbstractState *target);
    void removeTransition(QtAbstractTransition *transition);

#ifndef QT_NO_ANIMATION
    QtAnimationState *addAnimatedTransition(const QObject *sender, const char *signal, 
                                           QtAbstractState *targetState, 
                                           QtAbstractAnimation *animation = 0);
    QtAnimationState *addAnimatedTransition(QtAbstractTransition *transition,
                                           QtAbstractState *targetState, 
                                           QtAbstractAnimation *animation = 0);
#endif

    QtHistoryState *addHistoryState(HistoryType type = ShallowHistory);

    void setPropertyOnEntry(QObject *object, const char *name,
                            const QVariant &value);
    void setPropertyOnExit(QObject *object, const char *name,
                           const QVariant &value);
    void invokeMethodOnEntry(QObject *object, const char *method,
                             const QList<QVariant> &args = QList<QVariant>());
    void invokeMethodOnExit(QObject *object, const char *method,
                            const QList<QVariant> &args = QList<QVariant>());

    void addEntryAction(QtStateAction *action);
    void addExitAction(QtStateAction *action);

    void setRestorePolicy(RestorePolicy restorePolicy);
    RestorePolicy restorePolicy() const;

protected:
    QtAbstractStateGroup(QtAbstractStateGroup *parent = 0);

    void onEntry();
    void onExit();

protected:
    QtAbstractStateGroup(QtAbstractStateGroupPrivate &dd, QtAbstractStateGroup *parent);

private:
    Q_DISABLE_COPY(QtAbstractStateGroup)
    Q_DECLARE_PRIVATE(QtAbstractStateGroup)
};

QT_END_NAMESPACE

QT_END_HEADER

#endif
