/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QABSTRACTTRANSITION_H
#define QABSTRACTTRANSITION_H

#include <QtCore/qobject.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlist.h>

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)

class QEvent;
class QtAbstractState;

class QtAbstractTransitionPrivate;
class Q_ANIMATION_EXPORT QtAbstractTransition : public QObject
{
    Q_OBJECT
public:
    QtAbstractTransition(const QList<QEvent::Type> &eventTypes = QList<QEvent::Type>());
    QtAbstractTransition(QEvent::Type eventType);
    virtual ~QtAbstractTransition();

    QtAbstractState *sourceState() const;
    QList<QtAbstractState*> targetStates() const;

protected:
    virtual bool testCondition(QEvent *event) const;

    virtual void onTransition() = 0;

protected:
#ifdef QT_STATEMACHINE_SOLUTION
     QtAbstractTransitionPrivate *d_ptr;
#endif
    QtAbstractTransition(QtAbstractTransitionPrivate &dd,
                        const QList<QEvent::Type> &eventTypes);
    QtAbstractTransition(QtAbstractTransitionPrivate &dd,
                        QEvent::Type eventType);

private:
    Q_DISABLE_COPY(QtAbstractTransition)
    Q_DECLARE_PRIVATE(QtAbstractTransition)
};

QT_END_NAMESPACE

QT_END_HEADER

#endif
