/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QABSTRACTTRANSITION_P_H
#define QABSTRACTTRANSITION_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#ifndef QT_STATEMACHINE_SOLUTION
#include <private/qobject_p.h>
#endif

#include <QtCore/qcoreevent.h>
#include <QtCore/qlist.h>

QT_BEGIN_NAMESPACE

class QtAbstractState;
class QtStateMachine;

class QtAbstractTransition;
class Q_ANIMATION_EXPORT QtAbstractTransitionPrivate
#ifndef QT_STATEMACHINE_SOLUTION
    : public QObjectPrivate
#endif
{
    Q_DECLARE_PUBLIC(QtAbstractTransition)
public:
    QtAbstractTransitionPrivate();

    static QtAbstractTransitionPrivate *get(QtAbstractTransition *q);
    static const QtAbstractTransitionPrivate *get(const QtAbstractTransition *q);

    bool callTestCondition(QEvent *e) const;
    void callOnTransition();
    QtAbstractState *sourceState() const;
    QtStateMachine *machine() const;

    QList<QEvent::Type> eventTypes;
    QList<QtAbstractState*> targetStates;

#ifdef QT_STATEMACHINE_SOLUTION
    QtAbstractTransition *q_ptr;
#endif
};

QT_END_NAMESPACE

#endif
