/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QANIMATION_H
#define QANIMATION_H

#if defined(QT_EXPERIMENTAL_SOLUTION)
# include "qabstractanimation.h"
# include "qeasingcurve.h"
#else
# include <QtCore/qeasingcurve.h>
# include <QtCore/qabstractanimation.h>
#endif
#include <QtCore/qlist.h>
#include <QtCore/qpoint.h>
#include <QtCore/qvariant.h>
#include <QtCore/qpair.h>

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)

class QtAnimationPrivate;
class Q_ANIMATION_EXPORT QtAnimation : public QtAbstractAnimation
{
    Q_OBJECT
    Q_PROPERTY(QVariant startValue READ startValue WRITE setStartValue) /*NOTIFY startValueChanged*/
    Q_PROPERTY(QVariant endValue READ endValue WRITE setEndValue) /*NOTIFY endValueChanged*/
    Q_PROPERTY(QVariant currentValue READ currentValue NOTIFY valueChanged)
    Q_PROPERTY(int duration READ duration WRITE setDuration NOTIFY durationChanged)
    Q_PROPERTY(QtEasingCurve easingCurve READ easingCurve WRITE setEasingCurve) /*NOTIFY easingCurveChanged*/

public:
    typedef QPair<qreal, QVariant> KeyFrame;
    typedef QVector<KeyFrame> KeyFrames;

    QtAnimation(QObject *parent = 0);

    QVariant startValue() const;
    void setStartValue(const QVariant &value);

    QVariant endValue() const;
    void setEndValue(const QVariant &value);

    QVariant valueAt(qreal step) const;
    void setValueAt(qreal step, const QVariant &value);

    KeyFrames keyFrames() const;
    void setKeyFrames(const KeyFrames &values);

    QVariant currentValue() const;

    int duration() const;
    void setDuration(int msecs);

    QtEasingCurve easingCurve() const;
    void setEasingCurve(const QtEasingCurve &easing);

    typedef QVariant (*Interpolator)(const QVariant &from, const QVariant &to, qreal progress);
    static void registerInterpolator(Interpolator func, int interpolationType);

Q_SIGNALS:
    void valueChanged(const QVariant &value);
    void durationChanged(int msecs);

protected:
    QtAnimation(QtAnimationPrivate &dd, QObject *parent = 0);
    bool event(QEvent *event);

    QVariant defaultStartValue() const;
    void setDefaultStartValue(const QVariant &);

    void updateCurrentTime(int msecs);
    void updateState(QtAbstractAnimation::State oldState, QtAbstractAnimation::State newState);

    virtual void updateCurrentValue(const QVariant &value) = 0;
    virtual QVariant interpolated(const QVariant &from, const QVariant &to, qreal progress) const;

private:
    Q_DISABLE_COPY(QtAnimation)
    Q_DECLARE_PRIVATE(QtAnimation)
};

template <typename T>
static void qRegisterAnimationInterpolator(QtAnimation::Interpolator func
#ifndef qdoc
, T * /* dummy */ = 0
#endif
) {
    QtAnimation::registerInterpolator(func, qMetaTypeId<T>());
}


QT_END_NAMESPACE

#endif //QANIMATION_H
