/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QANIMATION_P_H
#define QANIMATION_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of QIODevice. This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qanimation.h"
#if defined(QT_EXPERIMENTAL_SOLUTION)
# include "qeasingcurve.h"
#else
# include <QtCore/qeasingcurve.h>
#endif
#include <QtCore/qmetaobject.h>
#include <QtCore/qvector.h>

#include "qabstractanimation_p.h"

QT_BEGIN_NAMESPACE

class Q_ANIMATION_EXPORT QtAnimationPrivate : public QtAbstractAnimationPrivate
{
    Q_DECLARE_PUBLIC(QtAnimation)
public:

    QtAnimationPrivate() : duration(250), hasStartValue(false)
    {
    }

    void init()
    {
        //we keep the mask so that we emit valueChanged only when needed (for performance reasons)
        changedSignalMask = (1 << q_func()->metaObject()->indexOfSignal("valueChanged(QVariant)"));
        currentInterval.start.first = currentInterval.end.first = 2; //will force the initial refresh
        interpolator = 0;
    }

    
    //some helper functions
    bool atBeginning() const
    {
        return currentTime == 0;
    }

    bool atEnd() const
    {
        return currentTime == duration && currentLoop == (loopCount - 1);
    }

    static QtAnimationPrivate *get(QtAnimation *q);

    int duration;
    QtEasingCurve easing;

    QtAnimation::KeyFrames keyFrames;
    QVariant currentValue;
    QVariant defaultStartValue;
    bool hasStartValue;
   
    //this is used to keep track of the keyframe interval in which we currently are
    struct
    {
        QtAnimation::KeyFrame start, end;
    } currentInterval;

    mutable QtAnimation::Interpolator interpolator;

    quint32 changedSignalMask;

    void updateCurrentValue();
    void setValueAt(qreal, const QVariant &);
    QVariant valueAt(qreal step) const;
    void convertValues(int t);
};

//this should make the interpolation faster
template<typename T> inline T _q_interpolate(const T &f,const T &t, qreal progress)
{
    return T(f + (t - f) * progress);
}

template<typename T > inline QVariant _q_interpolateVariant(const QVariant &f, const QVariant &t, qreal progress)
{
    const T from = qVariantValue<T>(f);
    const T to = qVariantValue<T>(t);
    return _q_interpolate(from, to, progress);
}


QT_END_NAMESPACE

#endif //QANIMATION_P_H
