/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


/*!
    \class QtPauseAnimation
    \brief The QtPauseAnimation class provides a pause for QtSequentialAnimationGroup.
    
    
    \preliminary
*/

#include "qpauseanimation.h"
#include "qabstractanimation_p.h"


QT_BEGIN_NAMESPACE

class QtPauseAnimationPrivate : public QtAbstractAnimationPrivate
{
public:
    QtPauseAnimationPrivate() : QtAbstractAnimationPrivate(), duration(0)
    {
    }

    int duration;
};

/*!
    Constructs a QtPauseAnimation.
    \a parent is passed to QObject's constructor.
    The default duration is 0.
*/

QtPauseAnimation::QtPauseAnimation(QObject *parent) : QtAbstractAnimation(*new QtPauseAnimationPrivate, parent)
{
}

/*!
    Constructs a QtPauseAnimation.
    \a msecs is the duration of the pause.
    \a parent is passed to QObject's constructor.
*/

QtPauseAnimation::QtPauseAnimation(int msecs, QObject *parent) : QtAbstractAnimation(*new QtPauseAnimationPrivate, parent)
{
    setDuration(msecs);
}


/*!
    \property QtPauseAnimation::duration
    \brief the duration of the pause.

    The duration of the pause. The duration should not be negative.
*/
int QtPauseAnimation::duration() const
{
    Q_D(const QtPauseAnimation);
    return d->duration;
}

void QtPauseAnimation::setDuration(int msecs)
{
    if (msecs < 0) {
        qWarning("QtPauseAnimation::setDuration: cannot set a negative duration");
        return;
    }
    Q_D(QtPauseAnimation);
    d->duration = msecs;
}

/*!
    \reimp
 */
bool QtPauseAnimation::event(QEvent *e)
{
    return QtAbstractAnimation::event(e);
}

/*!
    \reimp
 */
void QtPauseAnimation::updateCurrentTime(int msecs)
{
    Q_UNUSED(msecs);
}


QT_END_NAMESPACE

#include "moc_qpauseanimation.cpp"
