/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QSEQUENTIALANIMATIONGROUP_H
#define QSEQUENTIALANIMATIONGROUP_H

#if defined(QT_EXPERIMENTAL_SOLUTION)
# include "qanimationgroup.h"
#else
# include <QtCore/qanimationgroup.h>
#endif

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)

class QtPauseAnimation;
class QtSequentialAnimationGroupPrivate;

class Q_ANIMATION_EXPORT QtSequentialAnimationGroup : public QtAnimationGroup
{
    Q_OBJECT

public:
    QtSequentialAnimationGroup(QObject *parent = 0);
    ~QtSequentialAnimationGroup();

    QtPauseAnimation *addPause(int msecs);
    void insertAt(int index, QtAbstractAnimation *animation);
    QtPauseAnimation *insertPauseAt(int index, int msecs);

    QtAbstractAnimation *currentAnimation() const;
    int duration() const;

protected:
    QtSequentialAnimationGroup(QtSequentialAnimationGroupPrivate &dd, QObject *parent);

    void updateCurrentTime(int msecs);
    void updateState(QtAbstractAnimation::State oldState, QtAbstractAnimation::State newState);
    void updateDirection(QtAbstractAnimation::Direction direction);
    void animationInsertedAt(int index);
    void animationRemovedAt(int index);

private:
    Q_DISABLE_COPY(QtSequentialAnimationGroup)
    Q_DECLARE_PRIVATE(QtSequentialAnimationGroup)
    Q_PRIVATE_SLOT(d_func(), void _q_uncontrolledAnimationFinished())
};

QT_END_NAMESPACE

QT_END_HEADER

#endif //QSEQUENTIALANIMATIONGROUP_H
