/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QSTATEACTION_H
#define QSTATEACTION_H

#include <QtCore/qobject.h>

#include <QtCore/qvariant.h>
#include <QtCore/qlist.h>

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)

class QtStateActionPrivate;
class Q_ANIMATION_EXPORT QtStateAction : public QObject
{
    Q_OBJECT
public:
    ~QtStateAction();

protected:
    QtStateAction();

    virtual void execute() = 0;

protected:
#ifdef QT_STATEMACHINE_SOLUTION
    QtStateActionPrivate *d_ptr;
#endif
    QtStateAction(QtStateActionPrivate &dd);

private:
    Q_DISABLE_COPY(QtStateAction)
    Q_DECLARE_PRIVATE(QtStateAction)
};

class QtStateSetPropertyActionPrivate;
class Q_ANIMATION_EXPORT QtStateSetPropertyAction : public QtStateAction
{
    Q_OBJECT
public:
    QtStateSetPropertyAction(QObject *object, const char *name, const QVariant &value);
    ~QtStateSetPropertyAction();

    QVariant value() const;
    QByteArray propertyName() const;
    QObject *targetObject() const;

protected:
    void execute();

private:
    Q_DISABLE_COPY(QtStateSetPropertyAction)
    Q_DECLARE_PRIVATE(QtStateSetPropertyAction)
};

class QtStateInvokeMethodActionPrivate;
class Q_ANIMATION_EXPORT QtStateInvokeMethodAction : public QtStateAction
{
    Q_OBJECT
public:
    QtStateInvokeMethodAction(QObject *object, const char *method,
                             const QList<QVariant> &args = QList<QVariant>());
    ~QtStateInvokeMethodAction();

    QObject *targetObject() const;
    QByteArray methodSignature() const;

protected:
    void execute();

private:
    Q_DISABLE_COPY(QtStateInvokeMethodAction)
    Q_DECLARE_PRIVATE(QtStateInvokeMethodAction)
};

QT_END_NAMESPACE

QT_END_HEADER

#endif
