/****************************************************************************
**
** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
** Contact: Qt Software Information (qt-info@nokia.com)
**
** This file is part of a Qt Solutions component.
**
** GNU General Public License Usage
** This file may be used under the terms of the GNU
** General Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file.  Please review the following information
** to ensure GNU General Public Licensing requirements will be met:
** http://www.fsf.org/licensing/licenses/info/GPLv2.html and
** http://www.gnu.org/copyleft/gpl.html.  In addition, as a special
** exception, Nokia gives you certain additional rights. These rights
** are described in the Nokia Qt GPL Exception version 1.3, included in
** the file GPL_EXCEPTION.txt in this package.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at qt-sales@nokia.com.
**
****************************************************************************/


#ifndef QTRANSITION_H
#define QTRANSITION_H

#ifndef QT_STATEMACHINE_SOLUTION
#include <QtCore/qabstracttransition.h>
#else
#include "qabstracttransition.h"
#endif

#include <QtCore/qvariant.h>
#include <QtCore/qlist.h>

QT_BEGIN_HEADER

QT_BEGIN_NAMESPACE

QT_MODULE(Core)

class QtStateAction;

class QtTransitionPrivate;
class Q_ANIMATION_EXPORT QtTransition : public QtAbstractTransition
{
    Q_OBJECT
public:
    QtTransition(const QList<QEvent::Type> &eventTypes = QList<QEvent::Type>());
    QtTransition(QEvent::Type eventType);
    ~QtTransition();

    void setPropertyOnTransition(QObject *object, const char *name,
                                 const QVariant &value);
    void invokeMethodOnTransition(QObject *object, const char *method,
                                  const QList<QVariant> &args = QList<QVariant>());

    void addAction(QtStateAction *action);

protected:
    virtual void onTransition();

protected:
    QtTransition(QtTransitionPrivate &dd, const QList<QEvent::Type> &eventTypes);
    QtTransition(QtTransitionPrivate &dd, QEvent::Type eventType);

private:
    Q_DISABLE_COPY(QtTransition)
    Q_DECLARE_PRIVATE(QtTransition)
};

QT_END_NAMESPACE

QT_END_HEADER

#endif
